@@ -5,11 +5,11 @@ from dataclasses import asdict, dataclass
 
 import numpy as np
 from rpgpy.utils import rpg_seconds2datetime64
-from scipy.interpolate import interp1d
 from torch import Tensor, concat, from_numpy
 from torchmetrics.classification import BinaryConfusionMatrix
 
 IntTuples = tuple[tuple[int, int], ...]
+IntTuplesVariable = tuple[tuple[int, ...], ...]
 Ints = tuple[int, ...]
 
 
@@ -26,12 +26,32 @@ class VoodooOptions:
     n_dbins: int = 256
     z_limits: tuple[float, float] = (-50, 20)
     device: str = "cpu"
-    use_wandb: bool = False
 
     def dict(self) -> dict:
         return {k: str(v) for k, v in asdict(self).items()}
 
 
+@dataclass
+class WandbConfig:
+    project: str
+    name: str
+    entity: str
+
+
+@dataclass
+class VoodooTrainingOptions:
+    garbage: Ints = (0, 3, 7, 8, 9, 10)
+    groups: IntTuplesVariable = ((1, 5), (2, 4, 6))
+    dupe_droplets: int = 1
+    learning_rate: float = 1.0e-3
+    learning_rate_decay: float = 1.0e-1
+    learning_rate_decay_steps: int = 1
+    shuffle: bool = True
+    split: float = 0.1  # -> 10% of data for validation
+    wandb: WandbConfig | None = None
+    epochs: int = 3
+
+
 def time_grid(date: str, resolution: int = 30) -> np.ndarray:
     date_components = date.split("-")
     n_time = int(24 * 60 * 60 / resolution)
@@ -65,33 +85,6 @@ def arg_nearest(array: np.ndarray, value: float | int) -> np.int64:
     return i if i <= array.shape[0] - 1 else i - 1
 
 
-def interpolate_to_256(rpg_data: np.ndarray, rpg_header: dict) -> np.ndarray:
-    n_bins = 256
-    n_time, n_range, _ = rpg_data.shape
-    spec_new = np.zeros((n_time, n_range, n_bins))
-    chirp_limits = np.append(rpg_header["RngOffs"], n_range)
-
-    for ind, (ia, ib) in enumerate(zip(chirp_limits[:-1], chirp_limits[1:])):
-        spec = rpg_data[:, ia:ib, :]
-        if rpg_header["SpecN"][ind] == n_bins:
-            spec_new[:, ia:ib, :] = spec
-        else:
-            old = rpg_header["velocity_vectors"][ind]
-            iaa, ibb = int(np.argmin(old)), int(np.argmax(old)) + 1
-            old = old[iaa:ibb]
-            f = interp1d(
-                old,
-                spec[:, :, iaa:ibb],
-                axis=2,
-                bounds_error=False,
-                fill_value=-999.0,
-                kind="nearest",
-            )
-            spec_new[:, ia:ib, :] = f(np.linspace(old[0], old[-1], n_bins))
-
-    return spec_new
-
-
 def reshape(data: Tensor, mask: np.ndarray) -> np.ndarray:
     new_shape = mask.shape + (data.shape[1],)
     input_reshaped = np.zeros(new_shape)
@@ -105,25 +98,14 @@ def reshape(data: Tensor, mask: np.ndarray) -> np.ndarray:
     return input_reshaped
 
 
-def find_pattern(string: str) -> str | None:
-    """Search for date pattern in data path and return if found."""
-    regex = re.compile(r"\d{6}_")
-    match = regex.search(string)
-    # check if a match was found
-    if match:
-        # if a match was found, return the matched string
-        return match.group()[:-1]
-    return None
-
-
 def filter_list(rpg_lv0_files: list[str], date: list[str]) -> list[str | None]:
     regex = re.compile("".join(date))
     filtered_strings = filter(regex.search, rpg_lv0_files)
     return list(filtered_strings)
 
 
-def numpy_arrays2tensor(lists: list[np.ndarray]) -> Tensor:
-    torch_tensors = [from_numpy(np_array) for np_array in lists]
+def numpy_arrays2tensor(data: list[np.ndarray]) -> Tensor:
+    torch_tensors = [from_numpy(array) for array in data]
     return concat(torch_tensors, dim=0)
 
 
